@@ -56,6 +56,8 @@ ABB_RCF_CONF_TEMPLATE = {
                 "needles_pause": float,
             },
         },
+        "skip_all_pick_movements": bool,
+        "wait_at_place_egress": int,
         "robot_movement": {
             "global_speed_accel": {
                 "speed_override": float,
