@@ -6,11 +6,11 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
+import compas_rrc
 from compas.geometry import Frame
 from compas_fab.robots import Configuration
 from compas_fab.robots import JointTrajectory
 from compas_fab.robots import to_degrees
-from compas_rrc import RobotJoints
 
 try:
     from collections.abc import MutableSequence
@@ -19,7 +19,9 @@ except ImportError:
 
 try:
     from typing import Any
+    from typing import Callable
     from typing import List
+    from typing import Tuple
     from typing import Union
 except ImportError:
     pass
@@ -31,23 +33,23 @@ class _ListLike(MutableSequence):
     __slots__ = ()
 
     def __init__(self, list_):
-        self.list_ = list(list_)  # type: List
+        self._list = list(list_)  # type: List
 
     def __getitem__(self, index):  # type: (Union[int, slice]) -> Any
-        return self.list_[index]
+        return self._list[index]
 
     def __setitem__(self, index, item):  # type: (Union[int, slice], Any) -> None
-        self.list_[index] = item
+        self._list[index] = item
 
     def __delitem__(self, index):  # type: (Union[int, slice]) -> None
-        del self.list_[index]
+        del self._list[index]
 
     def __len__(self):  # type: () -> int
-        return len(self.list_)
+        return len(self._list)
 
     def insert(self, index, item):  # type: (int, Any) -> None
         """Insert element at specified index."""
-        self.list_.insert(index, item)
+        self._list.insert(index, item)
 
 
 class MinimalTrajectories(_ListLike):
@@ -62,11 +64,11 @@ class MinimalTrajectories(_ListLike):
         Trajectory points.
     """
 
-    __slots__ = "list_"
+    __slots__ = "_list"
 
-    def __init__(
+    def __init__(  # skipcq
         self, trajectories
-    ):  # type: (List[MinimalTrajectory]) -> None # skipcq
+    ):  # type: (List[MinimalTrajectory]) -> None
         super(MinimalTrajectories, self).__init__(trajectories)
 
     def __repr__(self):
@@ -75,11 +77,11 @@ class MinimalTrajectories(_ListLike):
     @property
     def trajectories(self):  # type: () -> List[MinimalTrajectory]
         """:obj:`list` : List of trajectories."""
-        return self.list_
+        return self._list
 
     @trajectories.setter
     def trajectories(self, trajectories):
-        self.list_ = trajectories
+        self._list = trajectories
 
     @property
     def data(self):  # type: () -> dict
@@ -142,14 +144,14 @@ class MinimalTrajectory(_ListLike):
         Trajectory points.
     """
 
-    __slots__ = "list_"
+    __slots__ = "_list"
 
     JOINT_TRAJECTORY = 0
     FRAME_TRAJECTORY = 1
 
-    def __init__(
+    def __init__(  # skipcq
         self, points
-    ):  # type: (List[Union[Frame, Configuration]]) -> None # skipcq
+    ):  # type: (List[Union[Frame, Configuration]]) -> None
         super(MinimalTrajectory, self).__init__(points)
 
     def __repr__(self):
@@ -158,11 +160,11 @@ class MinimalTrajectory(_ListLike):
     @property
     def points(self):  # type: () -> List[Union[Frame, Configuration]]
         """:obj:`list` : List of trajectory points."""
-        return self.list_
+        return self._list
 
     @points.setter
     def points(self, points):  # type: (List[Union[Frame, Configuration]]) -> None
-        self.list_ = points
+        self._list = points
 
     @property
     def data(self):  # type: () -> dict
@@ -193,10 +195,6 @@ class MinimalTrajectory(_ListLike):
                 "Trajectory contains more than one type of objects: {}".format(types)
             )
 
-    def as_robot_joints_points(self):  # type: () -> List[RobotJoints]
-        """:obj:`list` of :class:`compas_rrc.RobotJoints` : Trajectory as list of ``RobotJoints``."""  # noqa: E501
-        return [RobotJoints(*to_degrees(pt.values)) for pt in self.points]
-
     def copy(self):  # type: () -> MinimalTrajectory
         """Get an independent copy of object."""
         cls = type(self)
@@ -209,6 +207,20 @@ class MinimalTrajectory(_ListLike):
 
         return copy
 
+    def to_compas_rrc(
+        self,
+    ):  # type: () -> Tuple[Callable, List[Union[Frame, compas_rrc.RobotJoints]]]
+        if self.trajectory_type == self.FRAME_TRAJECTORY:
+            rrc_trajectory = self._list
+            rrc_instruction = compas_rrc.MoveToRobtarget
+        if self.trajectory_type == self.JOINT_TRAJECTORY:
+            rrc_trajectory = [
+                compas_rrc.RobotJoints(*to_degrees(pt.values)) for pt in self.points
+            ]
+            rrc_instruction = compas_rrc.MoveToJoints
+
+        return rrc_instruction, rrc_trajectory
+
     @classmethod
     def from_joint_trajectory(
         cls, joint_trajectory
