@@ -2,26 +2,14 @@
 ********************************************************************************
 rapid_clay_formations_fab.utils
 ********************************************************************************
-
 .. currentmodule:: rapid_clay_formations_fab.utils
-
-.. autosummary::
-    :toctree: generated/
-
-    ensure_frame
-    temp_change_compas_precision
-    wrap_list
 """
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import print_function
 
-import compas
 import compas.geometry as cg
 
-from rapid_clay_formations_fab.rhino import rgplane_to_cgframe
-from rapid_clay_formations_fab.rhino import rgpoint_to_cgpoint
-
 try:
     from typing import Any
 except ImportError:
@@ -80,6 +68,8 @@ def ensure_frame(frame_like):  # type: (Any) -> cg.Frame
 
     try:  # try to compare to Rhino objects
         import Rhino.Geometry as rg
+        from rapid_clay_formations_fab.rhino import rgplane_to_cgframe
+        from rapid_clay_formations_fab.rhino import rgpoint_to_cgpoint
 
         if isinstance(frame_like, rg.Plane):
             return rgplane_to_cgframe(frame_like)
@@ -92,21 +82,3 @@ def ensure_frame(frame_like):  # type: (Any) -> cg.Frame
     raise TypeError(
         "Can't convert {} to compas.geometry.Frame".format(type(frame_like))
     )
-
-
-def temp_change_compas_precision(precision):
-    """Decorate function to run with specified compas.PRECISION."""
-
-    def decorator(func):
-        def wrapped_func(*args, **kwargs):
-            prev_precision = compas.PRECISION
-            compas.PRECISION = precision
-
-            result = func(*args, **kwargs)
-
-            compas.PRECISION = prev_precision
-            return result
-
-        return wrapped_func
-
-    return decorator
